server_client_20141211_231026

### config2 : test_single_client_perf

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 1.29075694084 sec | 4.4879629612 sec

Error message: latency too high

Naarad report

### Metrics

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 161.33 | 161.33 | 161.33 | 161.33 | 161.33 | 161.33 | 161.33 | 161.33 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.085
server1-perf | latency | mean lt 0.33 | 0.0947821782178
server1-perf | qps | mean lt 7.0 | 101.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 161.333
client1-perf | latency | mean lt 35.0 | 161.333
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None